#
# spec file for package libvma
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
%define git_ver .0.731961ca9087
%define lib_major 8

Name:           libvma
Summary:        A library for boosting TCP and UDP traffic (over RDMA hardware)
License:        GPL-2.0-only OR BSD-2-Clause
Group:          Development/Libraries/C and C++
Version:        8.9.4
Release:        lp152.2.3.1
Source0:        %{name}-%{version}%{git_ver}.tar.gz
Source1:        vma.service
Patch0:         libvma-PIE.patch
Url:            https://github.com/Mellanox/libvma
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  libibverbs-devel
BuildRequires:  librdmacm-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libnl-3.0)
Requires:       libvma%{lib_major} = %{version}
ExclusiveArch:  x86_64 aarch64 ppc64le

%description
VMA library is a performance booster of TCP and UDP traffic
Part of Mellanox enhanced services
Allows application written over standard socket API
To run over Infiniband/Ethernet from userspace with full network stack bypass
and get better throughput, latency and packets/sec rate

%package       -n libvma%{lib_major}
Summary:        Libvma runtime libary
Group:          System/Libraries

%description -n libvma%{lib_major}
VMA library is a performance booster of TCP and UDP traffic
Part of Mellanox enhanced services
Allows application written over standard socket API
To run over Infiniband/Ethernet from userspace with full network stack bypass
and get better throughput, latency and packets/sec rate

%package        devel
Summary:        Header files and link required to develop with Libvma
Group:          Development/Libraries/C and C++
Requires:       libvma%{lib_major} = %{version}

%description devel
Headers and symbolink link required to compile and link with the Libvma library.

%prep
%setup -q -n  %{name}-%{version}%{git_ver}
%patch0 -p1

%build
./autogen.sh
export CXXFLAGS="%optflags -Wno-address-of-packed-member"
%configure --docdir=%{_docdir}/%{name}
make %{?_smp_mflags} V=1

%install
make DESTDIR=%{buildroot} install
rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}/etc/init.d/vma
rm -f %{buildroot}/etc/systemd/system/vma.service

install -D -m 755 tests/vma_perf_envelope/vma_perf_envelope.sh %{buildroot}/%{_datadir}/%{name}/vma_perf_envelope.sh
install -m 644 src/vma/vma_extra.h %{buildroot}/%{_includedir}/mellanox/vma_extra.h
install -m 644 src/vma/util/libvma.conf %{buildroot}/%{_sysconfdir}/
install -s -m 755 src/stats/vma_stats %{buildroot}/%{_bindir}/vma_stats
install -s -m 755 tools/daemon/vmad %{buildroot}/%{_sbindir}/vmad
install -D -m 644 %{S:1} %{buildroot}%{_unitdir}/vma.service

for service in vma; do ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc${service}; done

%post -n libvma%{lib_major} -p /sbin/ldconfig
%postun -n libvma%{lib_major} -p /sbin/ldconfig

%pre
%service_add_pre vma.service

%post
%service_add_post vma.service

%preun
%service_del_preun vma.service

%postun
%service_del_postun vma.service

%files
%defattr(-,root,root,-)
%dir %{_datadir}/%{name}
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/README.txt
%{_docdir}/%{name}/journal.txt
%{_docdir}/%{name}/VMA_VERSION
%config(noreplace) %{_sysconfdir}/libvma.conf
%config %{_sysconfdir}/security/limits.d/30-libvma-limits.conf
%{_sbindir}/vmad
%{_sbindir}/vma
%{_sbindir}/rcvma
%{_unitdir}/vma.service
%{_bindir}/vma_stats
%{_datadir}/%{name}/vma_perf_envelope.sh
%license COPYING

%files -n libvma%{lib_major}
%{_libdir}/%{name}*.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/mellanox
%{_libdir}/%{name}.so

%changelog
* Tue May 25 2021 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Added libvma-PIE.patch: Link the tools as position independent executables
  (bsc#1184124).
* Thu Sep 26 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 8.9.4
  * No short release notes available.
    See journal.txt for a complete list
* Fri Sep  6 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 8.9.2
  * No short release notes available.
    See journal.txt for a complete list
* Wed May 15 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 8.8.2
  * No short release notes available.
    See journal.txt for a complete list
* Mon Oct 15 2018 nmoreychaisemartin@suse.com
- Update to version 8.7.1 (fate#325994)
  * No short release notes available.
    See journal.txt for a complete list
- Removed issue-1417243-Fix-gcc8-build-warnings.patch as it
  was fixed upstream.
* Mon Jun 18 2018 nmoreychaisemartin@suse.com
- Update to version 8.6.7
  - No short release notes available
- Added issue-1417243-Fix-gcc8-build-warnings.patch to
  fix compilation issue with GCC8
* Wed Jan 24 2018 nmoreychaisemartin@suse.com
- Update to version 8.4.11
  - Added:
  - RM #1214451 Add systemd support for daemon
  - RM #1214453 Improve selection of filesystem monitor method
  - RM #1207424 Send quickack depending on the payload size
  - RM #1179641 Add MTU find logic to ring
  - RM #1190606 VMA stats - Remove timewait interval in last cycle
  - RM #1179641 Override MTU from route over interface MTU
  - RM #1179641 Add parsing route table metrics
  - RM #1190054 Rename VMA_SPEC parameter 6973 to 7750
  - RM #1176937 Add VMA_TCP_QUICKACK environment variable
  - RM #1176937 Add TCP_QUICKACK option support
  - RM #1176937 Add delayed ack control into LWIP
  - RM #1151606 Modify valgrind suppression file
  - RM #1182826 Check if the module parameters exists
  - RM #847360 Add Coverity badge to README.md
  - RM #1172255 Disable parser warning coverity checker
  - Fixed:
  - RM #1247358 Fix crash when VMA could not resolve neighbor
  - RM #1258245 Fix SYN messages are sent to invalid peer
  - RM #1250147 Reorder netlink event registration at startup
  - RM #1214453 Fix daemon for powerpc
  - RM #1214453 Fix issue in inotify processing
  - RM #1222660 Correct warning check for flow steering
  - RM #1192017 Fix ibv_destroy_cq() failure while VMA_TCP_3T_RULES=1
  - RM #1213984 Use dst_enty to find the route MTU
  - RM #1175479 Inherit missing properties from the parent
  - RM #1175657 Fix ring statistics are not updated was flowtag is enabled
  - RM #1201040 Fix VMA_BUFFER_BATCHING_MODE is ignored while set from spec
  - RM #1182981 Fix TCP zero-window probe message sequence number
  - RM #1181379 Fix TCP zero window probe when there is data in-flight
  - RM #1185978 Fix compilation for --enable-opt-log=high
  - RM #1164732 Fix possible deadlock during connect
  - RM #1185372 Fix traffic is not offloaded for high VMA_RX_WRE values
- Update vma.service to match upstream
* Tue Nov 14 2017 nmoreychaisemartin@suse.com
- Install COPYING file
* Wed Nov  8 2017 nmoreychaisemartin@suse.com
- Initial packaging of version 8.4.8
